@@ -85,8 +85,8 @@ def cmd_list(
     # However, APIs requests are slow, and most work items don't have a PR.
     # Instead, we'll retrieve all active PRs and see which items are linked (less API calls)
     repo_name = get_repo_name()
-    query = f"az repos pr list --repository '{repo_name}' --org '{organization}' -p '{project}' "
-    query += "--status active --query '[].pullRequestId'"
+    query = f'az repos pr list --repository "{repo_name}" --org "{organization}" -p "{project}" '
+    query += '--status active --query "[].pullRequestId"'
     active_pullrequest_ids = run_command(query)
 
     with Live(build_table(work_items, workitem_prs, iteration, False), refresh_per_second=4, console=console) as live:
@@ -95,7 +95,7 @@ def cmd_list(
         # Posted issue on bug here: https://github.com/Azure/azure-cli-extensions/issues/2946
         for pr_id in track(active_pullrequest_ids, description="Processing pull requests"):
             linked_workitems = run_command(
-                f"az repos pr work-item list --id {pr_id} --query '[].id' --org '{organization}'", allow_verbose=False
+                f'az repos pr work-item list --id {pr_id} --query "[].id" --org "{organization}"', allow_verbose=False
             )
             for work_item in linked_workitems:
                 if work_item in workitem_prs.keys():
