@@ -221,18 +221,24 @@ def run_command(command: str, allow_verbose=True):
     if allow_verbose and verbose_shell():
         console.print(f"[bright_black]{command}[/bright_black]")
 
-    encoding = guess_shell_encoding()
+    encoding = get_config("encoding", "")
+    if encoding == "":
+        encoding = guess_shell_encoding()
 
-    process = subprocess.run(
-        command,
-        stdin=subprocess.PIPE,
-        stdout=subprocess.PIPE,
-        stderr=subprocess.PIPE,
-        universal_newlines=True,
-        encoding=encoding,
-        shell=True,
-        timeout=15,
-    )
+    try:
+        process = subprocess.run(
+            command,
+            stdin=subprocess.PIPE,
+            stdout=subprocess.PIPE,
+            stderr=subprocess.PIPE,
+            universal_newlines=True,
+            encoding=encoding,
+            shell=True,
+            timeout=15,
+        )
+    except subprocess.TimeoutExpired as e:
+        console.print(e)
+        sys.exit(1)
 
     if process.returncode != 0:
         console.print(f"There was an error. Ran the following command with encoding '{encoding}':")
@@ -252,10 +258,12 @@ def run_command(command: str, allow_verbose=True):
         except Exception:
             console.print("[doing-cli] error: Could not process the following stdout as a JSON:")
             console.print(f"[dark_orange3]{process.stdout}[/dark_orange3]")
+            sys.exit(1)
     else:
         return []
 
 
+@lru_cache(maxsize=100)
 def guess_shell_encoding() -> str:
     """
     Try to determine the encoding used by host shell.
@@ -271,7 +279,10 @@ def guess_shell_encoding() -> str:
     # Same issue for windows powershell
     # how to detect:
     # https://stackoverflow.com/a/59459612/5525118
-    elif "powershell" in psutil.Process(os.getppid()).name():
+    process_name = str(psutil.Process(os.getppid()).name()).lower()
+    if "powershell" in process_name:
+        return "cp1252"
+    elif "cmd.exe" in process_name:
         return "cp1252"
     else:
         return sys.stdout.encoding
@@ -353,9 +364,9 @@ def get_current_pr_id() -> int:
     current_branch = get_git_current_branch()
     repo_name = get_repo_name()
 
-    cmd = "az repos pr list --status 'active' "
-    cmd += f"--repository '{repo_name}' --source-branch '{current_branch}' "
-    cmd += f"--project '{project}' --organization '{organization}'"
+    cmd = 'az repos pr list --status "active" '
+    cmd += f'--repository "{repo_name}" --source-branch "{current_branch}" '
+    cmd += f'--project "{project}" --organization "{organization}"'
 
     result = run_command(cmd)
 
